/*
 * Pictures Map showing photos from Panormaio for fixed area.
 * 
 * Created for Unfolding workshop at RCA.
 * (c) 2014 Till Nagel, tillnagel.com
 */ 
import de.fhpotsdam.unfolding.UnfoldingMap;
import de.fhpotsdam.unfolding.geo.Location;
import de.fhpotsdam.unfolding.utils.MapUtils;
import de.fhpotsdam.unfolding.utils.ScreenPosition;

String apiString = "http://www.panoramio.com/map/get_panoramas.php?set=public&from=0&to=20&size=square&mapfilter=true&minx=-0.235&miny=51.439&maxx=0.039&maxy=51.568";

ArrayList<Picture> pictures = new ArrayList<Picture>();
UnfoldingMap map;

void setup() {
  size(800, 600);

  map = new UnfoldingMap(this);
  map.zoomAndPanTo(new Location(51.500, -0.118), 12);
  MapUtils.createDefaultEventDispatcher(this, map);

  pictures = loadPictures();
  println("Loaded " + pictures.size() + " pictures");
}

void draw() {
  map.draw();
  
  for (Picture picture : pictures) {
    ScreenPosition pos = map.getScreenPosition(picture.location);
    image(picture.img, pos.x, pos.y);
  }
}




ArrayList<Picture> loadPictures() {
  ArrayList<Picture> pictures = new ArrayList<Picture>();

  JSONObject json = loadJSONObject(apiString);
  JSONArray photosArray = json.getJSONArray("photos");

  for (int i = 0; i < photosArray.size(); i++) {
    JSONObject photo = photosArray.getJSONObject(i);

    Picture picture = new Picture();
    picture.title = photo.getString("photo_title");
    double lng = photo.getDouble("longitude");
    double lat = photo.getDouble("latitude");
    picture.location = new Location(lat, lng);
    String imgUrl = photo.getString("photo_file_url");
    picture.img = loadImage(imgUrl);

    pictures.add(picture);
    println("Loaded picture " + picture.title); 
  }


  return pictures;
}

